@@ -248,7 +248,7 @@ class BC_set : public E_F0mps { public:
     {
       aType rr =  complextype ? atype<Complex>() : atype<double>();
       if (rr == atype<Complex>()) complextype= true; 
-      cout << " CastToK => " << complextype <<endl;
+      if(verbosity > 10) cout << " CastToK => " << complextype <<endl;
      for ( vector<pair<int,Expression> >::iterator k=bc.begin();k!=bc.end();k++)
 	k->second=CastTo<K>(C_F0(k->second,rr)) ;
     }
@@ -875,7 +875,7 @@ public:
 
 
 
-template<class K> class Matrice_Creuse  { 
+template<class K> class Matrice_Creuse  {
   //  CountPointer<FESpace> Uh,Vh;
   //pfes  *pUh,*pVh; // pointeur sur la variable stockant FESpace;  
 public:
@@ -883,12 +883,16 @@ public:
   //  const void * pUh,pVh; //  pointeur pour la reconstruction 
   CountPointer<MatriceCreuse<K> > A;  
   TypeSolveMat typemat;
+    size_t count;
   void init() {
+      count=0;
     A.init();Uh.init();Vh.init();
     typemat=TypeSolveMat(TypeSolveMat::NONESQUARE);}
   Matrice_Creuse() { init();}
-  void destroy() {
-    A.destroy();
+  void destroy() {// Correct Oct 2015 FH (avant test a 'envert) !!!!
+    if(count--==0)
+      A.destroy();
+//else count--;
     //    Uh.destroy();
     //Vh.destroy();
   }   
@@ -899,7 +903,7 @@ public:
   long N() const {return  A ? A->n : 0;}
   long M() const { return A ? A->m : 0;}
   void resize(int n,int m) { if(A) A->resize(n,m);}
-  
+  void increment(){ count++;}
 };
 
 template<class K> class Matrice_Creuse_Transpose;
